import 'package:cpt_main/router/component/main_service_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:initializer/app_initializer.dart';
import 'package:plugin_basic/basic_export.dart';
import 'package:plugin_basic/provider/app_config/app_config_service.dart';

import 'package:cs_resources/local/theme/theme_config.dart';
import 'package:plugin_basic/provider/global_provider_container.dart';
import 'package:router/componentRouter/component_service_manager.dart';
import 'package:cpt_profile/router/component/profile_service_provider.dart';
import 'package:plugin_basic/obs/my_navigator_observer.dart';
import 'package:widgets/dialog/custom_toast_widget.dart';
import 'package:widgets/dialog/custom_error_widget.dart';
import 'package:widgets/dialog/custom_failure_widget.dart';
import 'package:widgets/dialog/custom_success_widget.dart';
import 'package:widgets/dialog/custom_loading_widget.dart';
import 'package:widgets/widget_export.dart';

import 'router/page/app_page_router.dart';
import 'router/component/app_service_provider.dart';

void main() async {
  //运行App
  // FlutterBugly.postCatchedException(() async {
  //交给初始化构造器去统一初始化
  await AppInitializer.initializeRunalone();

  //组件路由的注入
  final serviceManager = ComponentServiceManager()
    ..addServiceProvider(mainServiceProvider)
    ..addServiceProvider(appServiceProvider)
    ..addServiceProvider(profileServiceProvider);

  runApp(ProviderScope(
    parent: globalContainer,
    child: MyApp(),
  ));
  // });
}

class MyApp extends StatelessWidget {
  MyApp({Key? key}) : super(key: key) {
    /// 全局设置 EasyRefresh 的样式
    EasyRefresh.defaultHeaderBuilder = () => const ClassicHeader(
          dragText: 'Pull to refresh',
          armedText: 'Release ready',
          readyText: 'Refreshing...',
          processingText: 'Refreshing...',
          processedText: 'Succeeded',
          noMoreText: 'No more',
          failedText: 'Failed',
          messageText: 'Last updated at %T',
          textStyle: TextStyle(color: Color(0XFFAECAE5), fontSize: 14),
          messageStyle: TextStyle(color: Color(0XFFAECAE5), fontSize: 12),
          iconTheme: IconThemeData(color: Color(0XFFAECAE5)),
          backgroundColor: Colors.transparent,
        );
    EasyRefresh.defaultFooterBuilder = () => const ClassicFooter(
          dragText: 'Pull to load',
          armedText: 'Release ready',
          readyText: 'Loading...',
          processingText: 'Loading...',
          processedText: 'Succeeded',
          noMoreText: 'No more',
          failedText: 'Failed',
          showMessage: false,
          triggerOffset: 50,
          iconDimension: 22,
          textStyle: TextStyle(color: Color(0XFFAECAE5), fontSize: 14),
          messageStyle: TextStyle(color: Color(0XFFAECAE5), fontSize: 12),
          iconTheme: IconThemeData(color: Color(0XFFAECAE5)),
          backgroundColor: Colors.transparent,
        );

    /// SmartDialog 配置
    SmartDialog.config
      ..custom = SmartConfigCustom(
        maskColor: Colors.black.withOpacity(0.35),
        useAnimation: true,
      )
      ..attach = SmartConfigAttach(
        animationType: SmartAnimationType.scale,
        usePenetrate: false,
      )
      ..loading = SmartConfigLoading(
        backDismiss: true,
        clickMaskDismiss: true,
      )
      ..toast = SmartConfigToast(
        intervalTime: const Duration(milliseconds: 100),
        displayTime: const Duration(milliseconds: 2000),
      );
  }

  @override
  Widget build(BuildContext context) {

    WidgetsBinding.instance.addPostFrameCallback((_) {
      AppConfigService.getInstance().initSize(context);
    });

    //设置全局的状态栏文本样式
    SystemChrome.setSystemUIOverlayStyle(ThemeConfig.systemUiOverlayStyleLightThemeWhite);

    //路由管理，状态管理，依赖管理一切都始于GetMaterialApp
    return KeyboardVisibilityBuilder(builder: (context, isKeyboardVisible) {
      return KeyboardDismissOnTap(
        dismissOnCapturedTaps: false,
        child: MaterialApp.router(
          title: 'PropertyManagementSystem',
          debugShowCheckedModeBanner: true,
          theme: ThemeData(
            colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
            useMaterial3: false,
          ),
          //AutoRouter的配置
          routerConfig: appRouter.config(
            navigatorObservers: () => [
              MyNavigatorObserver(),
            ],
          ),
          //SmartDialog初始化默认Loading与Toast
          builder: FlutterSmartDialog.init(
            toastBuilder: (String msg) {
              return CustomToastWidget(msg: msg);
            },
            loadingBuilder: (String msg) {
              return CustomLoadingWidget(msg: msg == 'loading...' ? 'Loading...' : msg);
            },
            notifyStyle: FlutterSmartNotifyStyle(
              successBuilder: (String msg) => CustomSuccessWidget(msg: msg),
              failureBuilder: (String msg) => CustomFailureWidget(msg: msg),
              errorBuilder: (String msg) => CustomErrorWidget(msg: msg),
              alertBuilder: (String msg) => CustomErrorWidget(msg: msg),
              warningBuilder: (String msg) => CustomErrorWidget(msg: msg),
            ),
          ),
        ),
      );
    });
  }
}
